0.2.8 (2023-03-13)
------------------

Exchangeable templates.

* Added the ability to exchange templates by using different template base directories
* Fixed backlink from comment to post when not using Javascript
